@@ -1,14 +1,12 @@
 # compatibility with older versions of R
 
 if(!("intercept" %in% names(formals(stats::reformulate)))) {
-
-`reformulate` <- function (termlabels, response = NULL, intercept = TRUE) {
-	ret <- stats::reformulate(termlabels, response = response)
-	if (!intercept) ret <- update.formula(ret, .~. -1)
-	attr(ret, ".Environment") <- parent.frame()
-	ret
-}
-
+	`reformulate` <- function (termlabels, response = NULL, intercept = TRUE) {
+		ret <- stats::reformulate(termlabels, response = response)
+		if (!intercept) ret <- update.formula(ret, .~. -1)
+		attr(ret, ".Environment") <- parent.frame()
+		ret
+	}
 }
 
 `DebugPrint` <- function(x) { cat(deparse(substitute(x)), "= \n") ; print(x) }
@@ -71,11 +69,11 @@ function(x) {
 	return (weight)
 }
 
-
-if (!existsFunction("nobs", where = "package:stats")) {
+if (!exists("nobs", mode = "function", where = "package:stats", inherits = FALSE)) {
 
 `nobs` <- function(object, ...) UseMethod("nobs")
 `nobs.default` <- function(object, ...) NROW(resid(object, ...))
+`nobs.glm` <- function (object, ...) sum(!is.na(object$residuals))
 
 }
 
